
# Type: default_range


default slot range to be used if range element is omitted from a slot definition

URI: [meta:default_range](https://w3id.org/biolink/biolinkml/meta/default_range)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>OPT</sub> [TypeDefinition](TypeDefinition.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
